



#install.packages('sampling')
#install.packages('survey')
#install.packages('sae')


library(sampling)   # survey sampling
library(survey)    # Analysis of Complex Survey Samples
library(sae)      # Small area estimation



# Load data set with synthetic income data for provinces (domains)
data("incomedata")
?incomedata
# Synthetic data on income and other related variables for Spanish provinces

#View(incomedata)
str(incomedata)
names(incomedata)
summary(incomedata)

# Load population sizes of provinces
data(sizeprov)
?sizeprov
# Identifiers and population sizes for domains in data set incomedata.

#View(sizeprov)
str(sizeprov)
names(sizeprov)
summary(sizeprov)

# Compute Horvitz-Thompson direct estimator of mean income for each
# province under simple random sampling without replacement within each province.

# Direct estimator: an estimator based only on area specific sample
# Design-based estimation: the main focus is on the design unbiasedness. 
# Estimators are unbiased with respect to the randomization that generates survey data

?direct

# Compute direct estimator of mean income for each province
# under SRS with replacement within each province

DIR_srs_rep <- direct(y=income, dom=prov, 
                      data=incomedata, replace=TRUE)
DIR_srs_rep

is.data.frame(DIR_srs_rep)

head(DIR_srs_rep)
names(DIR_srs_rep)
summary(DIR_srs_rep)

# Compute direct estimator of mean income for each province
# under SRS without replacement within each province 

HT_srs <- direct(y=income, dom=prov, sweight=weight,
                  domsize=sizeprov[,2:3], data=incomedata)
HT_srs

is.data.frame(HT_srs)

head(HT_srs)
names(HT_srs)
summary(HT_srs)

# Compute HT using HT function in sampling package and "by hand"

HT_samp=c()
HT_manual=c()

for(i in 1:nrow(sizeprov)){
  tmp_data=incomedata[incomedata$prov==i,]
  tmp_size=sizeprov[sizeprov$prov==i,]
  pik=(tmp_data$weight)^-1
  ht=HTestimator(tmp_data$income, pik)
  HT_samp[i]=ht/tmp_size$Nd
  HT_manual[i]=crossprod(tmp_data$income, 1/pik)/tmp_size$Nd
}

# Change domains of definition: Unplanned domain!

# Compute direct estimator of mean income for each province of Spanish or non Spanish
# under SRS 

data(sizeprovnat)
summary(sizeprovnat)
summary(sizeprov)

# smaller unplanned domains

HT_srs_spanish <- direct(y=income, dom=prov, sweight=weight,
                 domsize=sizeprovnat[,2:3], data=incomedata[incomedata$nat==1,])
HT_srs_spanish

head(HT_srs_spanish)
names(HT_srs_spanish)
summary(HT_srs_spanish)


# even smaller unplanned domain

HT_srs_no_spanish <- direct(y=income, dom=prov, sweight=weight,
                         domsize=sizeprovnat[,2:4], data=incomedata[incomedata$nat==2,])
HT_srs_no_spanish

head(HT_srs_no_spanish)
names(HT_srs_no_spanish)
summary(HT_srs_no_spanish)


# Some Plots

# Plot CV (Statistics Canada Classification)
# Unplanned Domains: No Spanish inside Provinces

cv_no_sp=HT_srs_no_spanish$CV

cv=unlist(c(cv_no_sp))
cv[unlist(c(cv_no_sp))<16.6]="C"
cv[unlist(c(cv_no_sp))>16.6 & unlist(c(cv_no_sp)) <33.3]="B"
cv[unlist(c(cv_no_sp))>33.3]="A"

tmp=as.factor(cv)


# Barplot
plot(tmp)

# Pie
counts = table(cv)  ## get counts
pie(counts, col=c(2,4,3), labels=c(">33.3", "16.6-33.3", "<16.6"))  ## plot


# CV and Samplesize

names(HT_srs_no_spanish)

dta=HT_srs_no_spanish[order(HT_srs_no_spanish$SampSize),]
head(dta)
View(dta)
plot(dta$CV, xlab="Increasing Sample Size", ylab="Direct CV")  
plot(dta$CV, type = "n",  ylab = "CVs",
     xlab = "area (Increasing Sample Size)", cex.axis = 1.5,
     cex.lab = 1.5)
points(dta$CV, type = "b", col = 1, lwd = 2, pch = 1, lty = 1)

plot(dta$Direct, type = "n",  ylab = "Estimate",
     xlab = "area (Increasing Sample Size)", cex.axis = 1.5,
     cex.lab = 1.5)
points(dta$Direct, type = "b", col = 2, lwd = 2, pch = 1, lty = 1)

dta=HT_srs_no_spanish[order(HT_srs_no_spanish$SampSize, decreasing=T),]
head(dta)
View(dta)
plot(dta$CV, xlab="Decreasing Sample Size", ylab="Direct CV")  
plot(dta$CV, type = "n",  ylab = "CVs",
     xlab = "area (Decreasing Sample Size)", cex.axis = 1.5,
     cex.lab = 1.5)
points(dta$CV, type = "b", col = 1, lwd = 2, pch = 1, lty = 1)

plot(dta$Direct, type = "n",  ylab = "Estimate",
     xlab = "area (Decreasing Sample Size)", cex.axis = 1.5,
     cex.lab = 1.5)
points(dta$Direct, type = "b", col = 2, lwd = 2, pch = 1, lty = 1)


